translate.misc.stdiotell.StdIOWrapper

Package translate :: Package misc :: Module stdiotell :: Class StdIOWrapper |
[hide private]
[frames] | no frames]

# Class StdIOWrapper

source code

Instance Methods | [hide private]
__init__(self, stream) | source code
__getattr__(self, attrname, default=None) | source code
close(self) | source code
seek(self, pos, mode=0) | source code
tell(self) | source code
write(self, s) | source code
writelines(self, lines) | source code